guix_mirror_bot pushed a commit to branch go-team
in repository guix.

commit 00187cdbbf8df2bb81ebd5a2c137e6bd92de292b
Author: Roman Scherer <[email protected]>
AuthorDate: Tue Apr 21 19:16:00 2026 +0200

    gnu: go-github-com-shirou-gopsutil-v4: Skip TestSwapDevices.
    
    TestSwapDevices reads /proc/swaps and fails when it is empty:
    SwapDevices() returns an empty list, which the test treats as a
    failure.
    
    * gnu/packages/golang-xyz.scm (go-github-com-shirou-gopsutil-v4)
    [arguments]<#:test-flags>: Skip TestSwapDevices.
    
    Relates-to: guix/guix!8004
    Change-Id: I5f7a9b2c3d4e5f6a7b8c9d0e1f2a3b4c5d6e7f89
    Signed-off-by: Sharlatan Hellseher <[email protected]>
---
 gnu/packages/golang-xyz.scm | 9 ++++++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/gnu/packages/golang-xyz.scm b/gnu/packages/golang-xyz.scm
index 7742e467ff..7924b03a8a 100644
--- a/gnu/packages/golang-xyz.scm
+++ b/gnu/packages/golang-xyz.scm
@@ -25651,7 +25651,9 @@ sensors).")
       ;; [1] error open /var/run/utmp: no such file or directory
       ;; [2] PlatformInformation() returns empty
       ;; [3] Could not get temperature
       ;; [4] TestCounts and TestInfo read /proc/cpuinfo fields that
       ;;     are absent on non-x86 Linux.
       #:test-flags
       #~(list "-skip"
@@ -25659,8 +25661,9 @@ sensors).")
                (append
                 (list "TestUsers"               ;1
                       "TestPlatformInformation" ;2
-                      "TestTemperatures")       ;3
-                (if #$(target-x86?)             ;4
+                      "TestTemperatures"        ;3
+                      "TestSwapDevices")        ;4
+                (if #$(target-x86?)             ;5
                     '()
                     (list "TestCounts" "TestInfo")))
                "|"))))))
@@ -25651,7 +25651,9 @@ sensors).")
       ;; [2] PlatformInformation() returns empty
       ;; [3] Could not get temperature
-      ;; [4] TestCounts and TestInfo read /proc/cpuinfo fields that
+      ;; [4] TestSwapDevices reads /proc/swaps and fails when no swap
+      ;;     devices are configured on the build host.
+      ;; [5] TestCounts and TestInfo read /proc/cpuinfo fields that
       ;;     are absent on non-x86 Linux.
       #:test-flags

Reply via email to